"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    studio_id: str,
    client_token: str = None,
    ec2_instance_type: str = None,
    launch_profile_id: str = None,
    streaming_image_id: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a streaming session in a studio. After invoking this operation, you must poll GetStreamingSession until the streaming session is in state READY.

    Args:
        client_token(str, optional): To make an idempotent API request using one of these actions, specify a client token in the request. You should not reuse the same client token for other API requests. If you retry a request that completed successfully using the same client token and the same parameters, the retry succeeds without performing any further actions. If you retry a successful request using the same client token, but one or more of the parameters are different, the retry fails with a ValidationException error. Defaults to None.
        ec2_instance_type(str, optional): The EC2 Instance type used for the streaming session. Defaults to None.
        launch_profile_id(str, optional): The launch profile ID. Defaults to None.
        streaming_image_id(str, optional): The ID of the streaming image. Defaults to None.
        studio_id(str): The studio ID.
        tags(Dict, optional): A collection of labels, in the form of key:value pairs, that apply to this resource. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.streaming.session.init.create(ctx, studio_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.streaming.session.init.create studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="create_streaming_session",
        op_kwargs={
            "clientToken": client_token,
            "ec2InstanceType": ec2_instance_type,
            "launchProfileId": launch_profile_id,
            "streamingImageId": streaming_image_id,
            "studioId": studio_id,
            "tags": tags,
        },
    )


async def delete(
    hub, ctx, session_id: str, studio_id: str, client_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes streaming session resource. After invoking this operation, use GetStreamingSession to poll the resource until it transitions to a DELETED state. A streaming session will count against your streaming session quota until it is marked DELETED.

    Args:
        client_token(str, optional): To make an idempotent API request using one of these actions, specify a client token in the request. You should not reuse the same client token for other API requests. If you retry a request that completed successfully using the same client token and the same parameters, the retry succeeds without performing any further actions. If you retry a successful request using the same client token, but one or more of the parameters are different, the retry fails with a ValidationException error. Defaults to None.
        session_id(str): The session ID.
        studio_id(str): The studio ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.streaming.session.init.delete(
                ctx, session_id=value, studio_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.streaming.session.init.delete session_id=value, studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="delete_streaming_session",
        op_kwargs={
            "clientToken": client_token,
            "sessionId": session_id,
            "studioId": studio_id,
        },
    )


async def get(hub, ctx, session_id: str, studio_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets StreamingSession resource. Invoke this operation to poll for a streaming session state while creating or deleting a session.

    Args:
        session_id(str): The session ID.
        studio_id(str): The studio ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.streaming.session.init.get(
                ctx, session_id=value, studio_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.streaming.session.init.get session_id=value, studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="get_streaming_session",
        op_kwargs={"sessionId": session_id, "studioId": studio_id},
    )


async def list_all(
    hub,
    ctx,
    studio_id: str,
    created_by: str = None,
    next_token: str = None,
    session_ids: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the streaming image resources in a studio.

    Args:
        created_by(str, optional): The user ID. Defaults to None.
        next_token(str, optional): The token for the next set of results, or null if there are no more results. Defaults to None.
        session_ids(str, optional): A collection of session IDs. Defaults to None.
        studio_id(str): The studio ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.nimble.streaming.session.init.list_all(ctx, studio_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.nimble.streaming.session.init.list_all studio_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="nimble",
        operation="list_streaming_sessions",
        op_kwargs={
            "createdBy": created_by,
            "nextToken": next_token,
            "sessionIds": session_ids,
            "studioId": studio_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub,
    ctx,
    config_rule_name: str,
    resource_keys: List = None,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Provides a detailed view of a Remediation Execution for a set of resources including state, timestamps for when steps for the remediation execution occur, and any error messages for steps that have failed. When you specify the limit and the next token, you receive a paginated response.

    Args:
        config_rule_name(str): A list of AWS Config rule names.
        resource_keys(List, optional): A list of resource keys to be processed with the current request. Each element in the list consists of the resource type and resource ID. . Defaults to None.
        limit(int, optional): The maximum number of RemediationExecutionStatuses returned on each page. The default is maximum. If you specify 0, AWS Config uses the default. . Defaults to None.
        next_token(str, optional): The nextToken string returned on a previous page that you use to get the next page of results in a paginated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.remediation.execution.status.describe(
                ctx, config_rule_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.remediation.execution.status.describe config_rule_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="describe_remediation_execution_status",
        op_kwargs={
            "ConfigRuleName": config_rule_name,
            "ResourceKeys": resource_keys,
            "Limit": limit,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def accept(hub, ctx, master_id: str, invitation_id: str) -> Dict:
    r"""
    **Autogenerated function**

    This method is deprecated. Instead, use AcceptAdministratorInvitation. The Security Hub console continues to use AcceptInvitation. It will eventually change to use AcceptAdministratorInvitation. Any IAM policies that specifically control access to this function must continue to use AcceptInvitation. You should also add AcceptAdministratorInvitation to your policies to ensure that the correct permissions are in place after the console begins to use AcceptAdministratorInvitation. Accepts the invitation to be a member account and be monitored by the Security Hub administrator account that the invitation was sent from. This operation is only used by member accounts that are not added through Organizations. When the member account accepts the invitation, permission is granted to the administrator account to view findings generated in the member account.

    Args:
        master_id(str): The account ID of the Security Hub administrator account that sent the invitation.
        invitation_id(str): The identifier of the invitation sent from the Security Hub administrator account.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.invitation.init.accept(
                ctx, master_id=value, invitation_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.invitation.init.accept master_id=value, invitation_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="accept_invitation",
        op_kwargs={"MasterId": master_id, "InvitationId": invitation_id},
    )


async def decline(hub, ctx, account_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Declines invitations to become a member account. This operation is only used by accounts that are not part of an organization. Organization accounts do not receive invitations.

    Args:
        account_ids(List): The list of account IDs for the accounts from which to decline the invitations to Security Hub.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.invitation.init.decline(ctx, account_ids=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.invitation.init.decline account_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="decline_invitations",
        op_kwargs={"AccountIds": account_ids},
    )


async def delete_multiple(hub, ctx, account_ids: List) -> Dict:
    r"""
    **Autogenerated function**

    Deletes invitations received by the Amazon Web Services account to become a member account. This operation is only used by accounts that are not part of an organization. Organization accounts do not receive invitations.

    Args:
        account_ids(List): The list of the account IDs that sent the invitations to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.invitation.init.delete_multiple(
                ctx, account_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.invitation.init.delete_multiple account_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="delete_invitations",
        op_kwargs={"AccountIds": account_ids},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists all Security Hub membership invitations that were sent to the current Amazon Web Services account. This operation is only used by accounts that are managed by invitation. Accounts that are managed using the integration with Organizations do not receive invitations.

    Args:
        max_results(int, optional): The maximum number of items to return in the response. . Defaults to None.
        next_token(str, optional): The token that is required for pagination. On your first call to the ListInvitations operation, set the value of this parameter to NULL. For subsequent calls to the operation, to continue listing data, set the value of this parameter to the value returned from the previous response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.invitation.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.invitation.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="list_invitations",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub,
    ctx,
    application_id: str,
    campaign_id: str,
    page_size: str = None,
    token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about all the activities for a campaign.

    Args:
        application_id(str): The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.
        campaign_id(str): The unique identifier for the campaign.
        page_size(str, optional): The maximum number of items to include in each page of a paginated response. This parameter is not supported for application, campaign, and journey metrics. Defaults to None.
        token(str, optional): The NextToken string that specifies which page of results to return in a paginated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.campaign.activity.get_all(
                ctx, application_id=value, campaign_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.campaign.activity.get_all application_id=value, campaign_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="get_campaign_activities",
        op_kwargs={
            "ApplicationId": application_id,
            "CampaignId": campaign_id,
            "PageSize": page_size,
            "Token": token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(
    hub, ctx, enable_termination_protection: bool, stack_name: str
) -> Dict:
    r"""
    **Autogenerated function**

    Updates termination protection for the specified stack. If a user attempts to delete a stack with termination protection enabled, the operation fails and the stack remains unchanged. For more information, see Protecting a Stack From Being Deleted in the CloudFormation User Guide.  For nested stacks, termination protection is set on the root stack and cannot be changed directly on the nested stack.

    Args:
        enable_termination_protection(bool): Whether to enable termination protection on the specified stack.
        stack_name(str): The name or unique ID of the stack for which you want to set termination protection.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.termination_protection.update(
                ctx, enable_termination_protection=value, stack_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.termination_protection.update enable_termination_protection=value, stack_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="update_termination_protection",
        op_kwargs={
            "EnableTerminationProtection": enable_termination_protection,
            "StackName": stack_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"list_": "list"}


async def list_(
    hub,
    ctx,
    hit_id: str,
    next_token: str = None,
    max_results: int = None,
    assignment_statuses: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

     The ListAssignmentsForHIT operation retrieves completed assignments for a HIT. You can use this operation to retrieve the results for a HIT.   You can get assignments for a HIT at any time, even if the HIT is not yet Reviewable. If a HIT requested multiple assignments, and has received some results but has not yet become Reviewable, you can still retrieve the partial results with this operation.   Use the AssignmentStatus parameter to control which set of assignments for a HIT are returned. The ListAssignmentsForHIT operation can return submitted assignments awaiting approval, or it can return assignments that have already been approved or rejected. You can set AssignmentStatus=Approved,Rejected to get assignments that have already been approved and rejected together in one result set.   Only the Requester who created the HIT can retrieve the assignments for that HIT.   Results are sorted and divided into numbered pages and the operation returns a single page of results. You can use the parameters of the operation to control sorting and pagination.

    Args:
        hit_id(str): The ID of the HIT.
        next_token(str, optional): Pagination token. Defaults to None.
        max_results(int, optional): . Defaults to None.
        assignment_statuses(List, optional): The status of the assignments to return: Submitted | Approved | Rejected. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mturk.assignment.for_hit.list(ctx, hit_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mturk.assignment.for_hit.list hit_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mturk",
        operation="list_assignments_for_hit",
        op_kwargs={
            "HITId": hit_id,
            "NextToken": next_token,
            "MaxResults": max_results,
            "AssignmentStatuses": assignment_statuses,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def add(hub, ctx, resource_type: str, resource_id: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Adds or overwrites one or more tags for the specified resource. Tags are metadata that you can assign to your documents, managed instances, maintenance windows, Parameter Store parameters, and patch baselines. Tags enable you to categorize your resources in different ways, for example, by purpose, owner, or environment. Each tag consists of a key and an optional value, both of which you define. For example, you could define a set of tags for your account's managed instances that helps you track each instance's owner and stack level. For example:    Key=Owner,Value=DbAdmin     Key=Owner,Value=SysAdmin     Key=Owner,Value=Dev     Key=Stack,Value=Production     Key=Stack,Value=Pre-Production     Key=Stack,Value=Test    Each resource can have a maximum of 50 tags. We recommend that you devise a set of tag keys that meets your needs for each resource type. Using a consistent set of tag keys makes it easier for you to manage your resources. You can search and filter the resources based on the tags you add. Tags don't have any semantic meaning to and are interpreted strictly as a string of characters.  For more information about using tags with Amazon Elastic Compute Cloud (Amazon EC2) instances, see Tagging your Amazon EC2 resources in the Amazon EC2 User Guide.

    Args:
        resource_type(str): Specifies the type of resource you are tagging.  The ManagedInstance type for this API operation is for on-premises managed instances. You must specify the name of the managed instance in the following format: mi-ID_number . For example, mi-1a2b3c4d5e6f. .
        resource_id(str): The resource ID you want to tag. Use the ID of the resource. Here are some examples:  MaintenanceWindow: mw-012345abcde   PatchBaseline: pb-012345abcde   OpsMetadata object: ResourceID for tagging is created from the Amazon Resource Name (ARN) for the object. Specifically, ResourceID is created from the strings that come after the word opsmetadata in the ARN. For example, an OpsMetadata object with an ARN of arn:aws:ssm:us-east-2:1234567890:opsmetadata/aws/ssm/MyGroup/appmanager has a ResourceID of either aws/ssm/MyGroup/appmanager or /aws/ssm/MyGroup/appmanager. For the Document and Parameter values, use the name of the resource.  ManagedInstance: mi-012345abcde   The ManagedInstance type for this API operation is only for on-premises managed instances. You must specify the name of the managed instance in the following format: mi-ID_number . For example, mi-1a2b3c4d5e6f. .
        tags(List): One or more tags. The value parameter is required.  Don't enter personally identifiable information in this field. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.tags.to_resource.add(
                ctx, resource_type=value, resource_id=value, tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.tags.to_resource.add resource_type=value, resource_id=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="add_tags_to_resource",
        op_kwargs={
            "ResourceType": resource_type,
            "ResourceId": resource_id,
            "Tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about the specified AWS FIS action.

    Args:
        id_(str): The ID of the action.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fis.action.get(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fis.action.get id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="fis", operation="get_action", op_kwargs={"id": id_}
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the available AWS FIS actions.

    Args:
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.fis.action.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.fis.action.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="fis",
        operation="list_actions",
        op_kwargs={"maxResults": max_results, "nextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def attach(
    hub,
    ctx,
    device_index: int,
    instance_id: str,
    network_interface_id: str,
    dry_run: bool = None,
    network_card_index: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Attaches a network interface to an instance.

    Args:
        device_index(int): The index of the device for the network interface attachment.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        instance_id(str): The ID of the instance.
        network_interface_id(str): The ID of the network interface.
        network_card_index(int, optional): The index of the network card. Some instance types support multiple network cards. The primary network interface must be assigned to network card index 0. The default is network card index 0. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.network.interface.init.attach(
                ctx, device_index=value, instance_id=value, network_interface_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.network.interface.init.attach device_index=value, instance_id=value, network_interface_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="attach_network_interface",
        op_kwargs={
            "DeviceIndex": device_index,
            "DryRun": dry_run,
            "InstanceId": instance_id,
            "NetworkInterfaceId": network_interface_id,
            "NetworkCardIndex": network_card_index,
        },
    )


async def create(
    hub,
    ctx,
    subnet_id: str,
    description: str = None,
    dry_run: bool = None,
    groups: List = None,
    ipv6_address_count: int = None,
    ipv6_addresses: List = None,
    private_ip_address: str = None,
    private_ip_addresses: List = None,
    secondary_private_ip_address_count: int = None,
    ipv4_prefixes: List = None,
    ipv4_prefix_count: int = None,
    ipv6_prefixes: List = None,
    ipv6_prefix_count: int = None,
    interface_type: str = None,
    tag_specifications: List = None,
    client_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a network interface in the specified subnet. For more information about network interfaces, see Elastic Network Interfaces in the Amazon Virtual Private Cloud User Guide.

    Args:
        description(str, optional): A description for the network interface. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        groups(List, optional): The IDs of one or more security groups. Defaults to None.
        ipv6_address_count(int, optional): The number of IPv6 addresses to assign to a network interface. Amazon EC2 automatically selects the IPv6 addresses from the subnet range. You can't use this option if specifying specific IPv6 addresses. If your subnet has the AssignIpv6AddressOnCreation attribute set to true, you can specify 0 to override this setting. Defaults to None.
        ipv6_addresses(List, optional): One or more specific IPv6 addresses from the IPv6 CIDR block range of your subnet. You can't use this option if you're specifying a number of IPv6 addresses. Defaults to None.
        private_ip_address(str, optional): The primary private IPv4 address of the network interface. If you don't specify an IPv4 address, Amazon EC2 selects one for you from the subnet's IPv4 CIDR range. If you specify an IP address, you cannot indicate any IP addresses specified in privateIpAddresses as primary (only one IP address can be designated as primary). Defaults to None.
        private_ip_addresses(List, optional): One or more private IPv4 addresses. Defaults to None.
        secondary_private_ip_address_count(int, optional): The number of secondary private IPv4 addresses to assign to a network interface. When you specify a number of secondary IPv4 addresses, Amazon EC2 selects these IP addresses within the subnet's IPv4 CIDR range. You can't specify this option and specify more than one private IP address using privateIpAddresses. The number of IP addresses you can assign to a network interface varies by instance type. For more information, see IP Addresses Per ENI Per Instance Type in the Amazon Virtual Private Cloud User Guide. Defaults to None.
        ipv4_prefixes(List, optional): One or moreIPv4 Prefix Delegation prefixes assigned to the network interface. You cannot use this option if you use the Ipv4PrefixCount option. Defaults to None.
        ipv4_prefix_count(int, optional): The number of IPv4 Prefix Delegation prefixes that AWS automatically assigns to the network interface. You cannot use this option if you use the Ipv4 Prefixes option. Defaults to None.
        ipv6_prefixes(List, optional): One or moreIPv6 Prefix Delegation prefixes assigned to the network interface. You cannot use this option if you use the Ipv6PrefixCount option. Defaults to None.
        ipv6_prefix_count(int, optional): The number of IPv6 Prefix Delegation prefixes that AWS automatically assigns to the network interface. You cannot use this option if you use the Ipv6Prefixes option. Defaults to None.
        interface_type(str, optional): Indicates the type of network interface. To create an Elastic Fabric Adapter (EFA), specify efa. For more information, see  Elastic Fabric Adapter in the Amazon Elastic Compute Cloud User Guide. To create a trunk network interface, specify efa. For more information, see  Network interface trunking in the Amazon Elastic Compute Cloud User Guide. Defaults to None.
        subnet_id(str): The ID of the subnet to associate with the network interface.
        tag_specifications(List, optional): The tags to apply to the new network interface. Defaults to None.
        client_token(str, optional): Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. For more information, see Ensuring Idempotency. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.network.interface.init.create(ctx, subnet_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.network.interface.init.create subnet_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_network_interface",
        op_kwargs={
            "Description": description,
            "DryRun": dry_run,
            "Groups": groups,
            "Ipv6AddressCount": ipv6_address_count,
            "Ipv6Addresses": ipv6_addresses,
            "PrivateIpAddress": private_ip_address,
            "PrivateIpAddresses": private_ip_addresses,
            "SecondaryPrivateIpAddressCount": secondary_private_ip_address_count,
            "Ipv4Prefixes": ipv4_prefixes,
            "Ipv4PrefixCount": ipv4_prefix_count,
            "Ipv6Prefixes": ipv6_prefixes,
            "Ipv6PrefixCount": ipv6_prefix_count,
            "InterfaceType": interface_type,
            "SubnetId": subnet_id,
            "TagSpecifications": tag_specifications,
            "ClientToken": client_token,
        },
    )


async def delete(hub, ctx, network_interface_id: str, dry_run: bool = None) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified network interface. You must detach the network interface before you can delete it.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        network_interface_id(str): The ID of the network interface.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.network.interface.init.delete(
                ctx, network_interface_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.network.interface.init.delete network_interface_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_network_interface",
        op_kwargs={"DryRun": dry_run, "NetworkInterfaceId": network_interface_id},
    )


async def describe_all(
    hub,
    ctx,
    filters: List = None,
    dry_run: bool = None,
    network_interface_ids: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more of your network interfaces.

    Args:
        filters(List, optional): One or more filters.    addresses.private-ip-address - The private IPv4 addresses associated with the network interface.    addresses.primary - Whether the private IPv4 address is the primary IP address associated with the network interface.     addresses.association.public-ip - The association ID returned when the network interface was associated with the Elastic IP address (IPv4).    addresses.association.owner-id - The owner ID of the addresses associated with the network interface.    association.association-id - The association ID returned when the network interface was associated with an IPv4 address.    association.allocation-id - The allocation ID returned when you allocated the Elastic IP address (IPv4) for your network interface.    association.ip-owner-id - The owner of the Elastic IP address (IPv4) associated with the network interface.    association.public-ip - The address of the Elastic IP address (IPv4) bound to the network interface.    association.public-dns-name - The public DNS name for the network interface (IPv4).    attachment.attachment-id - The ID of the interface attachment.    attachment.attach-time - The time that the network interface was attached to an instance.    attachment.delete-on-termination - Indicates whether the attachment is deleted when an instance is terminated.    attachment.device-index - The device index to which the network interface is attached.    attachment.instance-id - The ID of the instance to which the network interface is attached.    attachment.instance-owner-id - The owner ID of the instance to which the network interface is attached.    attachment.status - The status of the attachment (attaching | attached | detaching | detached).    availability-zone - The Availability Zone of the network interface.    description - The description of the network interface.    group-id - The ID of a security group associated with the network interface.    group-name - The name of a security group associated with the network interface.    ipv6-addresses.ipv6-address - An IPv6 address associated with the network interface.    mac-address - The MAC address of the network interface.    network-interface-id - The ID of the network interface.    owner-id - The Amazon Web Services account ID of the network interface owner.    private-ip-address - The private IPv4 address or addresses of the network interface.    private-dns-name - The private DNS name of the network interface (IPv4).    requester-id - The alias or Amazon Web Services account ID of the principal or service that created the network interface.    requester-managed - Indicates whether the network interface is being managed by an Amazon Web Service (for example, Amazon Web Services Management Console, Auto Scaling, and so on).    source-dest-check - Indicates whether the network interface performs source/destination checking. A value of true means checking is enabled, and false means checking is disabled. The value must be false for the network interface to perform network address translation (NAT) in your VPC.     status - The status of the network interface. If the network interface is not attached to an instance, the status is available; if a network interface is attached to an instance the status is in-use.    subnet-id - The ID of the subnet for the network interface.    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    vpc-id - The ID of the VPC for the network interface.  . Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        network_interface_ids(List, optional): One or more network interface IDs. Default: Describes all your network interfaces. Defaults to None.
        next_token(str, optional): The token to retrieve the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of items to return for this request. The request returns a token that you can specify in a subsequent call to get the next set of results. You cannot specify this parameter and the network interface IDs parameter in the same request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.network.interface.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.network.interface.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_network_interfaces",
        op_kwargs={
            "Filters": filters,
            "DryRun": dry_run,
            "NetworkInterfaceIds": network_interface_ids,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def detach(
    hub, ctx, attachment_id: str, dry_run: bool = None, force: bool = None
) -> None:
    r"""
    **Autogenerated function**

    Detaches a network interface from an instance.

    Args:
        attachment_id(str): The ID of the attachment.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        force(bool, optional): Specifies whether to force a detachment.    Use the Force parameter only as a last resort to detach a network interface from a failed instance.    If you use the Force parameter to detach a network interface, you might not be able to attach a different network interface to the same index on the instance without first stopping and starting the instance.   If you force the detachment of a network interface, the instance metadata might not get updated. This means that the attributes associated with the detached network interface might still be visible. The instance metadata will get updated when you stop and start the instance.   . Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.network.interface.init.detach(ctx, attachment_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.network.interface.init.detach attachment_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="detach_network_interface",
        op_kwargs={"AttachmentId": attachment_id, "DryRun": dry_run, "Force": force},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    server_properties: bytes,
    description: str = None,
    kafka_versions: List = None,
) -> Dict:
    r"""
        **Autogenerated function**


        Creates a new MSK configuration.


        Args:
            description(str, optional):
    The description of the configuration.
    . Defaults to None.
            kafka_versions(List, optional):
    The versions of Apache Kafka with which you can use this MSK configuration.
    . Defaults to None.
            name(str):
    The name of the configuration.
    .
            server_properties(bytes):
    Contents of the server.properties file. When using the API, you must ensure that the contents of the file are base64 encoded.
                   When using the AWS Management Console, the SDK, or the AWS CLI, the contents of server.properties can be in plaintext.
    .

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.kafka.configuration.init.create(
                    ctx, name=value, server_properties=value
                )

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.kafka.configuration.init.create name=value, server_properties=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kafka",
        operation="create_configuration",
        op_kwargs={
            "Description": description,
            "KafkaVersions": kafka_versions,
            "Name": name,
            "ServerProperties": server_properties,
        },
    )


async def delete(hub, ctx, arn: str) -> Dict:
    r"""
        **Autogenerated function**


        Deletes an MSK Configuration.


        Args:
            arn(str):
    The Amazon Resource Name (ARN) that uniquely identifies an MSK configuration.
    .

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.kafka.configuration.init.delete(ctx, arn=value)

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.kafka.configuration.init.delete arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kafka",
        operation="delete_configuration",
        op_kwargs={"Arn": arn},
    )


async def describe(hub, ctx, arn: str) -> Dict:
    r"""
        **Autogenerated function**


        Returns a description of this MSK configuration.


        Args:
            arn(str):
    The Amazon Resource Name (ARN) that uniquely identifies an MSK configuration and all of its revisions.
    .

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.kafka.configuration.init.describe(ctx, arn=value)

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.kafka.configuration.init.describe arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kafka",
        operation="describe_configuration",
        op_kwargs={"Arn": arn},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
        **Autogenerated function**


        Returns a list of all the MSK configurations in this Region.


        Args:
            max_results(int, optional):
    The maximum number of results to return in the response. If there are more results, the response includes a NextToken parameter.
    . Defaults to None.
            next_token(str, optional):
    The paginated results marker. When the result of the operation is truncated, the call returns NextToken in the response.
                To get the next batch, provide this token in your next request.
    . Defaults to None.

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.kafka.configuration.init.list_all(ctx)

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.kafka.configuration.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kafka",
        operation="list_configurations",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(
    hub, ctx, arn: str, server_properties: bytes, description: str = None
) -> Dict:
    r"""
        **Autogenerated function**


        Updates an MSK configuration.


        Args:
            arn(str):
    The Amazon Resource Name (ARN) of the configuration.
    .
            description(str, optional):
    The description of the configuration revision.
    . Defaults to None.
            server_properties(bytes):
    Contents of the server.properties file. When using the API, you must ensure that the contents of the file are base64 encoded.
                   When using the AWS Management Console, the SDK, or the AWS CLI, the contents of server.properties can be in plaintext.
    .

        Returns:
            Dict

        Examples:
            Call from code:

            .. code-block:: python

                await hub.exec.aws_auto.kafka.configuration.init.update(
                    ctx, arn=value, server_properties=value
                )

            Call from CLI:

            .. code-block:: bash

                $ idem exec aws_auto.kafka.configuration.init.update arn=value, server_properties=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kafka",
        operation="update_configuration",
        op_kwargs={
            "Arn": arn,
            "Description": description,
            "ServerProperties": server_properties,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    resource_group_name: str,
    ops_center_enabled: bool = None,
    cwe_monitor_enabled: bool = None,
    ops_item_sns_topic_arn: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds an application that is created from a resource group.

    Args:
        resource_group_name(str): The name of the resource group.
        ops_center_enabled(bool, optional):  When set to true, creates opsItems for any problems detected on an application. . Defaults to None.
        cwe_monitor_enabled(bool, optional):  Indicates whether Application Insights can listen to CloudWatch events for the application resources, such as instance terminated, failed deployment, and others. . Defaults to None.
        ops_item_sns_topic_arn(str, optional):  The SNS topic provided to Application Insights that is associated to the created opsItem. Allows you to receive notifications for updates to the opsItem. . Defaults to None.
        tags(List, optional): List of tags to add to the application. tag key (Key) and an associated tag value (Value). The maximum length of a tag key is 128 characters. The maximum length of a tag value is 256 characters. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_insight.application.create(
                ctx, resource_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_insight.application.create resource_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-insights",
        operation="create_application",
        op_kwargs={
            "ResourceGroupName": resource_group_name,
            "OpsCenterEnabled": ops_center_enabled,
            "CWEMonitorEnabled": cwe_monitor_enabled,
            "OpsItemSNSTopicArn": ops_item_sns_topic_arn,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, resource_group_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes the specified application from monitoring. Does not delete the application.

    Args:
        resource_group_name(str): The name of the resource group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_insight.application.delete(
                ctx, resource_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_insight.application.delete resource_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-insights",
        operation="delete_application",
        op_kwargs={"ResourceGroupName": resource_group_name},
    )


async def describe(hub, ctx, resource_group_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes the application.

    Args:
        resource_group_name(str): The name of the resource group.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_insight.application.describe(
                ctx, resource_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_insight.application.describe resource_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-insights",
        operation="describe_application",
        op_kwargs={"ResourceGroupName": resource_group_name},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the IDs of the applications that you are monitoring.

    Args:
        max_results(int, optional): The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned NextToken value. Defaults to None.
        next_token(str, optional): The token to request the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_insight.application.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_insight.application.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-insights",
        operation="list_applications",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(
    hub,
    ctx,
    resource_group_name: str,
    ops_center_enabled: bool = None,
    cwe_monitor_enabled: bool = None,
    ops_item_sns_topic_arn: str = None,
    remove_sns_topic: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the application.

    Args:
        resource_group_name(str): The name of the resource group.
        ops_center_enabled(bool, optional):  When set to true, creates opsItems for any problems detected on an application. . Defaults to None.
        cwe_monitor_enabled(bool, optional):  Indicates whether Application Insights can listen to CloudWatch events for the application resources, such as instance terminated, failed deployment, and others. . Defaults to None.
        ops_item_sns_topic_arn(str, optional):  The SNS topic provided to Application Insights that is associated to the created opsItem. Allows you to receive notifications for updates to the opsItem. Defaults to None.
        remove_sns_topic(bool, optional):  Disassociates the SNS topic from the opsItem created for detected problems. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.application_insight.application.update(
                ctx, resource_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.application_insight.application.update resource_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="application-insights",
        operation="update_application",
        op_kwargs={
            "ResourceGroupName": resource_group_name,
            "OpsCenterEnabled": ops_center_enabled,
            "CWEMonitorEnabled": cwe_monitor_enabled,
            "OpsItemSNSTopicArn": ops_item_sns_topic_arn,
            "RemoveSNSTopic": remove_sns_topic,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    app_id: str,
    domain_name: str,
    sub_domain_settings: List,
    enable_auto_sub_domain: bool = None,
    auto_sub_domain_creation_patterns: List = None,
    auto_sub_domain_iam_role: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Creates a new domain association for an Amplify app. This action associates a custom domain with the Amplify app

    Args:
        app_id(str):  The unique ID for an Amplify app. .
        domain_name(str):  The domain name for the domain association. .
        enable_auto_sub_domain(bool, optional):  Enables the automated creation of subdomains for branches. . Defaults to None.
        sub_domain_settings(List):  The setting for the subdomain. .
        auto_sub_domain_creation_patterns(List, optional):  Sets the branch patterns for automatic subdomain creation. . Defaults to None.
        auto_sub_domain_iam_role(str, optional):  The required AWS Identity and Access Management (IAM) service role for the Amazon Resource Name (ARN) for automatically creating subdomains. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplify.domain_association.create(
                ctx, app_id=value, domain_name=value, sub_domain_settings=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplify.domain_association.create app_id=value, domain_name=value, sub_domain_settings=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplify",
        operation="create_domain_association",
        op_kwargs={
            "appId": app_id,
            "domainName": domain_name,
            "enableAutoSubDomain": enable_auto_sub_domain,
            "subDomainSettings": sub_domain_settings,
            "autoSubDomainCreationPatterns": auto_sub_domain_creation_patterns,
            "autoSubDomainIAMRole": auto_sub_domain_iam_role,
        },
    )


async def delete(hub, ctx, app_id: str, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

     Deletes a domain association for an Amplify app.

    Args:
        app_id(str):  The unique id for an Amplify app. .
        domain_name(str):  The name of the domain. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplify.domain_association.delete(
                ctx, app_id=value, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplify.domain_association.delete app_id=value, domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplify",
        operation="delete_domain_association",
        op_kwargs={"appId": app_id, "domainName": domain_name},
    )


async def get(hub, ctx, app_id: str, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

     Returns the domain information for an Amplify app.

    Args:
        app_id(str):  The unique id for an Amplify app. .
        domain_name(str):  The name of the domain. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplify.domain_association.get(
                ctx, app_id=value, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplify.domain_association.get app_id=value, domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplify",
        operation="get_domain_association",
        op_kwargs={"appId": app_id, "domainName": domain_name},
    )


async def list_all(
    hub, ctx, app_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

     Returns the domain associations for an Amplify app.

    Args:
        app_id(str):  The unique ID for an Amplify app. .
        next_token(str, optional):  A pagination token. Set to null to start listing apps from the start. If non-null, a pagination token is returned in a result. Pass its value in here to list more projects. . Defaults to None.
        max_results(int, optional):  The maximum number of records to list in a single response. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplify.domain_association.list_all(ctx, app_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplify.domain_association.list_all app_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplify",
        operation="list_domain_associations",
        op_kwargs={"appId": app_id, "nextToken": next_token, "maxResults": max_results},
    )


async def update(
    hub,
    ctx,
    app_id: str,
    domain_name: str,
    sub_domain_settings: List,
    enable_auto_sub_domain: bool = None,
    auto_sub_domain_creation_patterns: List = None,
    auto_sub_domain_iam_role: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Creates a new domain association for an Amplify app.

    Args:
        app_id(str):  The unique ID for an Amplify app. .
        domain_name(str):  The name of the domain. .
        enable_auto_sub_domain(bool, optional):  Enables the automated creation of subdomains for branches. . Defaults to None.
        sub_domain_settings(List):  Describes the settings for the subdomain. .
        auto_sub_domain_creation_patterns(List, optional):  Sets the branch patterns for automatic subdomain creation. . Defaults to None.
        auto_sub_domain_iam_role(str, optional):  The required AWS Identity and Access Management (IAM) service role for the Amazon Resource Name (ARN) for automatically creating subdomains. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplify.domain_association.update(
                ctx, app_id=value, domain_name=value, sub_domain_settings=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplify.domain_association.update app_id=value, domain_name=value, sub_domain_settings=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplify",
        operation="update_domain_association",
        op_kwargs={
            "appId": app_id,
            "domainName": domain_name,
            "enableAutoSubDomain": enable_auto_sub_domain,
            "subDomainSettings": sub_domain_settings,
            "autoSubDomainCreationPatterns": auto_sub_domain_creation_patterns,
            "autoSubDomainIAMRole": auto_sub_domain_iam_role,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def modify(
    hub,
    ctx,
    db_cluster_identifier: str,
    capacity: int = None,
    seconds_before_timeout: int = None,
    timeout_action: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Set the capacity of an Aurora Serverless DB cluster to a specific value. Aurora Serverless scales seamlessly based on the workload on the DB cluster. In some cases, the capacity might not scale fast enough to meet a sudden change in workload, such as a large number of new transactions. Call ModifyCurrentDBClusterCapacity to set the capacity explicitly. After this call sets the DB cluster capacity, Aurora Serverless can automatically scale the DB cluster based on the cooldown period for scaling up and the cooldown period for scaling down. For more information about Aurora Serverless, see Using Amazon Aurora Serverless in the Amazon Aurora User Guide.  If you call ModifyCurrentDBClusterCapacity with the default TimeoutAction, connections that prevent Aurora Serverless from finding a scaling point might be dropped. For more information about scaling points, see  Autoscaling for Aurora Serverless in the Amazon Aurora User Guide.   This action only applies to Aurora DB clusters.

    Args:
        db_cluster_identifier(str): The DB cluster identifier for the cluster being modified. This parameter isn't case-sensitive. Constraints:   Must match the identifier of an existing DB cluster.  .
        capacity(int, optional): The DB cluster capacity. When you change the capacity of a paused Aurora Serverless DB cluster, it automatically resumes. Constraints:   For Aurora MySQL, valid capacity values are 1, 2, 4, 8, 16, 32, 64, 128, and 256.   For Aurora PostgreSQL, valid capacity values are 2, 4, 8, 16, 32, 64, 192, and 384.  . Defaults to None.
        seconds_before_timeout(int, optional): The amount of time, in seconds, that Aurora Serverless tries to find a scaling point to perform seamless scaling before enforcing the timeout action. The default is 300.   Value must be from 10 through 600.  . Defaults to None.
        timeout_action(str, optional): The action to take when the timeout is reached, either ForceApplyCapacityChange or RollbackCapacityChange.  ForceApplyCapacityChange, the default, sets the capacity to the specified value as soon as possible.  RollbackCapacityChange ignores the capacity change if a scaling point isn't found in the timeout period. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.rds.current_db_cluster_capacity.modify(
                ctx, db_cluster_identifier=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.rds.current_db_cluster_capacity.modify db_cluster_identifier=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="rds",
        operation="modify_current_db_cluster_capacity",
        op_kwargs={
            "DBClusterIdentifier": db_cluster_identifier,
            "Capacity": capacity,
            "SecondsBeforeTimeout": seconds_before_timeout,
            "TimeoutAction": timeout_action,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub,
    ctx,
    configuration_aggregator_name: str,
    filters: Dict = None,
    group_by_key: str = None,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the resource counts across accounts and regions that are present in your AWS Config aggregator. You can request the resource counts by providing filters and GroupByKey. For example, if the input contains accountID 12345678910 and region us-east-1 in filters, the API returns the count of resources in account ID 12345678910 and region us-east-1. If the input contains ACCOUNT_ID as a GroupByKey, the API returns resource counts for all source accounts that are present in your aggregator.

    Args:
        configuration_aggregator_name(str): The name of the configuration aggregator.
        filters(Dict, optional): Filters the results based on the ResourceCountFilters object. Defaults to None.
        group_by_key(str, optional): The key to group the resource counts. Defaults to None.
        limit(int, optional): The maximum number of GroupedResourceCount objects returned on each page. The default is 1000. You cannot specify a number greater than 1000. If you specify 0, AWS Config uses the default. Defaults to None.
        next_token(str, optional): The nextToken string returned on a previous page that you use to get the next page of results in a paginated response. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.aggregate.discovered_resource.count.get_all(
                ctx, configuration_aggregator_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.aggregate.discovered_resource.count.get_all configuration_aggregator_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="get_aggregate_discovered_resource_counts",
        op_kwargs={
            "ConfigurationAggregatorName": configuration_aggregator_name,
            "Filters": filters,
            "GroupByKey": group_by_key,
            "Limit": limit,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, api_id: str, domain_name: str, stage: str, api_mapping_key: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an API mapping.

    Args:
        api_id(str): The API identifier.
        api_mapping_key(str, optional): The API mapping key. Defaults to None.
        domain_name(str): The domain name.
        stage(str): The API stage.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.api.mapping.create(
                ctx, api_id=value, domain_name=value, stage=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.api.mapping.create api_id=value, domain_name=value, stage=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="create_api_mapping",
        op_kwargs={
            "ApiId": api_id,
            "ApiMappingKey": api_mapping_key,
            "DomainName": domain_name,
            "Stage": stage,
        },
    )


async def delete(hub, ctx, api_mapping_id: str, domain_name: str) -> None:
    r"""
    **Autogenerated function**

    Deletes an API mapping.

    Args:
        api_mapping_id(str): The API mapping identifier.
        domain_name(str): The domain name.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.api.mapping.delete(
                ctx, api_mapping_id=value, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.api.mapping.delete api_mapping_id=value, domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="delete_api_mapping",
        op_kwargs={"ApiMappingId": api_mapping_id, "DomainName": domain_name},
    )


async def get(hub, ctx, api_mapping_id: str, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets an API mapping.

    Args:
        api_mapping_id(str): The API mapping identifier.
        domain_name(str): The domain name.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.api.mapping.get(
                ctx, api_mapping_id=value, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.api.mapping.get api_mapping_id=value, domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="get_api_mapping",
        op_kwargs={"ApiMappingId": api_mapping_id, "DomainName": domain_name},
    )


async def get_all(
    hub, ctx, domain_name: str, max_results: str = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets API mappings.

    Args:
        domain_name(str): The domain name.
        max_results(str, optional): The maximum number of elements to be returned for this resource. Defaults to None.
        next_token(str, optional): The next page of elements from this collection. Not valid for the last element of the collection. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.api.mapping.get_all(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.api.mapping.get_all domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="get_api_mappings",
        op_kwargs={
            "DomainName": domain_name,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def update(
    hub,
    ctx,
    api_id: str,
    api_mapping_id: str,
    domain_name: str,
    api_mapping_key: str = None,
    stage: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    The API mapping.

    Args:
        api_id(str): The API identifier.
        api_mapping_id(str): The API mapping identifier.
        api_mapping_key(str, optional): The API mapping key. Defaults to None.
        domain_name(str): The domain name.
        stage(str, optional): The API stage. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apigatewayv2.api.mapping.update(
                ctx, api_id=value, api_mapping_id=value, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apigatewayv2.api.mapping.update api_id=value, api_mapping_id=value, domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apigatewayv2",
        operation="update_api_mapping",
        op_kwargs={
            "ApiId": api_id,
            "ApiMappingId": api_mapping_id,
            "ApiMappingKey": api_mapping_key,
            "DomainName": domain_name,
            "Stage": stage,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def confirm(
    hub,
    ctx,
    client_id: str,
    username: str,
    confirmation_code: str,
    secret_hash: str = None,
    force_alias_creation: bool = None,
    analytics_metadata: Dict = None,
    user_context_data: Dict = None,
    client_metadata: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Confirms registration of a user and handles the existing alias from a previous user.

    Args:
        client_id(str): The ID of the app client associated with the user pool.
        secret_hash(str, optional): A keyed-hash message authentication code (HMAC) calculated using the secret key of a user pool client and username plus the client ID in the message. Defaults to None.
        username(str): The user name of the user whose registration you wish to confirm.
        confirmation_code(str): The confirmation code sent by a user's request to confirm registration.
        force_alias_creation(bool, optional): Boolean to be specified to force user confirmation irrespective of existing alias. By default set to False. If this parameter is set to True and the phone number/email used for sign up confirmation already exists as an alias with a different user, the API call will migrate the alias from the previous user to the newly created user being confirmed. If set to False, the API will throw an AliasExistsException error. Defaults to None.
        analytics_metadata(Dict, optional): The Amazon Pinpoint analytics metadata for collecting metrics for ConfirmSignUp calls. Defaults to None.
        user_context_data(Dict, optional): Contextual data such as the user's device fingerprint, IP address, or location used for evaluating the risk of an unexpected event by Amazon Cognito advanced security. Defaults to None.
        client_metadata(Dict, optional): A map of custom key-value pairs that you can provide as input for any custom workflows that this action triggers.  You create custom workflows by assigning Lambda functions to user pool triggers. When you use the ConfirmSignUp API action, Amazon Cognito invokes the function that is assigned to the post confirmation trigger. When Amazon Cognito invokes this function, it passes a JSON payload, which the function receives as input. This payload contains a clientMetadata attribute, which provides the data that you assigned to the ClientMetadata parameter in your ConfirmSignUp request. In your function code in Lambda, you can process the clientMetadata value to enhance your workflow for your specific needs. For more information, see Customizing User Pool Workflows with Lambda Triggers in the Amazon Cognito Developer Guide.  Take the following limitations into consideration when you use the ClientMetadata parameter:   Amazon Cognito does not store the ClientMetadata value. This data is available only to Lambda triggers that are assigned to a user pool to support custom workflows. If your user pool configuration does not include triggers, the ClientMetadata parameter serves no purpose.   Amazon Cognito does not validate the ClientMetadata value.   Amazon Cognito does not encrypt the the ClientMetadata value, so don't use it to provide sensitive information.   . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cognito_idp.sign.up.confirm(
                ctx, client_id=value, username=value, confirmation_code=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cognito_idp.sign.up.confirm client_id=value, username=value, confirmation_code=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cognito-idp",
        operation="confirm_sign_up",
        op_kwargs={
            "ClientId": client_id,
            "SecretHash": secret_hash,
            "Username": username,
            "ConfirmationCode": confirmation_code,
            "ForceAliasCreation": force_alias_creation,
            "AnalyticsMetadata": analytics_metadata,
            "UserContextData": user_context_data,
            "ClientMetadata": client_metadata,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(hub, ctx, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists all exported output values in the account and Region in which you call this action. Use this action to see the exported output values that you can import into other stacks. To import values, use the  Fn::ImportValue  function.  For more information, see  CloudFormation Export Stack Output Values.

    Args:
        next_token(str, optional): A string (provided by the ListExports response output) that identifies the next page of exported output values that you asked to retrieve. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.export.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.export.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="list_exports",
        op_kwargs={"NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(hub, ctx, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.  For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference. Retrieves the identifiers of all of the HSMs provisioned for the current customer. This operation supports pagination with the use of the NextToken member. If more results are available, the NextToken member of the response contains a token that you pass in the next call to ListHsms to retrieve the next set of items.

    Args:
        next_token(str, optional): The NextToken value from a previous call to ListHsms. Pass null if this is the first call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudhsm.hsms.list(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudhsm.hsms.list
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudhsm",
        operation="list_hsms",
        op_kwargs={"NextToken": next_token},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def restart(
    hub, ctx, environment_id: str = None, environment_name: str = None
) -> None:
    r"""
    **Autogenerated function**

    Causes the environment to restart the application container server running on each Amazon EC2 instance.

    Args:
        environment_id(str, optional): The ID of the environment to restart the server for.  Condition: You must specify either this or an EnvironmentName, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error. . Defaults to None.
        environment_name(str, optional): The name of the environment to restart the server for.  Condition: You must specify either this or an EnvironmentId, or both. If you do not specify either, AWS Elastic Beanstalk returns MissingRequiredParameter error. . Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticbeanstalk.app.server.restart(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticbeanstalk.app.server.restart
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticbeanstalk",
        operation="restart_app_server",
        op_kwargs={
            "EnvironmentId": environment_id,
            "EnvironmentName": environment_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Returns the current role and list of Amazon S3 log buckets used by the Shield Response Team (SRT) to access your Amazon Web Services account while assisting with attack mitigation.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.shield.drt.access.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.shield.drt.access.describe
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="shield", operation="describe_drt_access", op_kwargs={}
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "default_kms_key_id"


async def get(hub, ctx, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Describes the default KMS key for EBS encryption by default for your account in this Region. You can change the default KMS key for encryption by default using ModifyEbsDefaultKmsKeyId or ResetEbsDefaultKmsKeyId. For more information, see Amazon EBS encryption in the Amazon Elastic Compute Cloud User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.ebs.default_kms_key_id_.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.ebs.default_kms_key_id.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="get_ebs_default_kms_key_id",
        op_kwargs={"DryRun": dry_run},
    )


async def modify(hub, ctx, kms_key_id: str, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Changes the default KMS key for EBS encryption by default for your account in this Region. Amazon Web Services creates a unique Amazon Web Services managed KMS key in each Region for use with encryption by default. If you change the default KMS key to a symmetric customer managed KMS key, it is used instead of the Amazon Web Services managed KMS key. To reset the default KMS key to the Amazon Web Services managed KMS key for EBS, use ResetEbsDefaultKmsKeyId. Amazon EBS does not support asymmetric KMS keys. If you delete or disable the customer managed KMS key that you specified for use with encryption by default, your instances will fail to launch. For more information, see Amazon EBS encryption in the Amazon Elastic Compute Cloud User Guide.

    Args:
        kms_key_id(str): The identifier of the Key Management Service (KMS) KMS key to use for Amazon EBS encryption. If this parameter is not specified, your KMS key for Amazon EBS is used. If KmsKeyId is specified, the encrypted state must be true. You can specify the KMS key using any of the following:   Key ID. For example, 1234abcd-12ab-34cd-56ef-1234567890ab.   Key alias. For example, alias/ExampleAlias.   Key ARN. For example, arn:aws:kms:us-east-1:012345678910:key/1234abcd-12ab-34cd-56ef-1234567890ab.   Alias ARN. For example, arn:aws:kms:us-east-1:012345678910:alias/ExampleAlias.   Amazon Web Services authenticates the KMS key asynchronously. Therefore, if you specify an ID, alias, or ARN that is not valid, the action can appear to complete, but eventually fails. Amazon EBS does not support asymmetric KMS keys.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.ebs.default_kms_key_id_.modify(ctx, kms_key_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.ebs.default_kms_key_id.modify kms_key_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_ebs_default_kms_key_id",
        op_kwargs={"KmsKeyId": kms_key_id, "DryRun": dry_run},
    )


async def reset(hub, ctx, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Resets the default KMS key for EBS encryption for your account in this Region to the Amazon Web Services managed KMS key for EBS. After resetting the default KMS key to the Amazon Web Services managed KMS key, you can continue to encrypt by a customer managed KMS key by specifying it when you create the volume. For more information, see Amazon EBS encryption in the Amazon Elastic Compute Cloud User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.ebs.default_kms_key_id_.reset(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.ebs.default_kms_key_id.reset
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="reset_ebs_default_kms_key_id",
        op_kwargs={"DryRun": dry_run},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx, shard_iterator: str, limit: int = None) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the stream records from a given shard. Specify a shard iterator using the ShardIterator parameter. The shard iterator specifies the position in the shard from which you want to start reading stream records sequentially. If there are no stream records available in the portion of the shard that the iterator points to, GetRecords returns an empty list. Note that it might take multiple calls to get to a portion of the shard that contains stream records.   GetRecords can retrieve a maximum of 1 MB of data or 1000 stream records, whichever comes first.

    Args:
        shard_iterator(str): A shard iterator that was retrieved from a previous GetShardIterator operation. This iterator can be used to access the stream records in this shard.
        limit(int, optional): The maximum number of records to return from the shard. The upper limit is 1000. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.dynamodbstream.record.get_all(ctx, shard_iterator=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.dynamodbstream.record.get_all shard_iterator=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="dynamodbstreams",
        operation="get_records",
        op_kwargs={"ShardIterator": shard_iterator, "Limit": limit},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"set_": "set"}


async def clear(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Clears the default authorizer.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.default.authorizer.clear(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.default.authorizer.clear
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="iot", operation="clear_default_authorizer", op_kwargs={}
    )


async def describe(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Describes the default authorizer.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.default.authorizer.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.default.authorizer.describe
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="iot", operation="describe_default_authorizer", op_kwargs={}
    )


async def set_(hub, ctx, authorizer_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Sets the default authorizer. This will be used if a websocket connection is made without specifying an authorizer.

    Args:
        authorizer_name(str): The authorizer name.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.default.authorizer.set(ctx, authorizer_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.default.authorizer.set authorizer_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="set_default_authorizer",
        op_kwargs={"authorizerName": authorizer_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create_multiple(
    hub,
    ctx,
    subdirectory: str,
    server_hostname: str,
    on_prem_config: Dict,
    mount_options: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Defines a file system on a Network File System (NFS) server that can be read from or written to.

    Args:
        subdirectory(str): The subdirectory in the NFS file system that is used to read data from the NFS source location or write data to the NFS destination. The NFS path should be a path that's exported by the NFS server, or a subdirectory of that path. The path should be such that it can be mounted by other NFS clients in your network.  To see all the paths exported by your NFS server, run "showmount -e nfs-server-name" from an NFS client that has access to your server. You can specify any directory that appears in the results, and any subdirectory of that directory. Ensure that the NFS export is accessible without Kerberos authentication.  To transfer all the data in the folder you specified, DataSync needs to have permissions to read all the data. To ensure this, either configure the NFS export with no_root_squash, or ensure that the permissions for all of the files that you want DataSync allow read access for all users. Doing either enables the agent to read the files. For the agent to access directories, you must additionally enable all execute access. If you are copying data to or from your AWS Snowcone device, see NFS Server on AWS Snowcone for more information. For information about NFS export configuration, see 18.7. The /etc/exports Configuration File in the Red Hat Enterprise Linux documentation.
        server_hostname(str): The name of the NFS server. This value is the IP address or Domain Name Service (DNS) name of the NFS server. An agent that is installed on-premises uses this host name to mount the NFS server in a network.  If you are copying data to or from your AWS Snowcone device, see NFS Server on AWS Snowcone for more information.  This name must either be DNS-compliant or must be an IP version 4 (IPv4) address. .
        on_prem_config(Dict): Contains a list of Amazon Resource Names (ARNs) of agents that are used to connect to an NFS server.  If you are copying data to or from your AWS Snowcone device, see NFS Server on AWS Snowcone for more information.
        mount_options(Dict, optional): The NFS mount options that DataSync can use to mount your NFS share. Defaults to None.
        tags(List, optional): The key-value pair that represents the tag that you want to add to the location. The value can be an empty string. We recommend using tags to name your resources. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datasync.location.nf.create_multiple(
                ctx, subdirectory=value, server_hostname=value, on_prem_config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datasync.location.nf.create_multiple subdirectory=value, server_hostname=value, on_prem_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datasync",
        operation="create_location_nfs",
        op_kwargs={
            "Subdirectory": subdirectory,
            "ServerHostname": server_hostname,
            "OnPremConfig": on_prem_config,
            "MountOptions": mount_options,
            "Tags": tags,
        },
    )


async def describe_all(hub, ctx, location_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns metadata, such as the path information, about an NFS location.

    Args:
        location_arn(str): The Amazon Resource Name (ARN) of the NFS location to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datasync.location.nf.describe_all(ctx, location_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datasync.location.nf.describe_all location_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datasync",
        operation="describe_location_nfs",
        op_kwargs={"LocationArn": location_arn},
    )


async def update_multiple(
    hub,
    ctx,
    location_arn: str,
    subdirectory: str = None,
    on_prem_config: Dict = None,
    mount_options: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates some of the parameters of a previously created location for Network File System (NFS) access. For information about creating an NFS location, see Creating a location for NFS.

    Args:
        location_arn(str): The Amazon Resource Name (ARN) of the NFS location to update.
        subdirectory(str, optional): The subdirectory in the NFS file system that is used to read data from the NFS source location or write data to the NFS destination. The NFS path should be a path that's exported by the NFS server, or a subdirectory of that path. The path should be such that it can be mounted by other NFS clients in your network. To see all the paths exported by your NFS server, run "showmount -e nfs-server-name" from an NFS client that has access to your server. You can specify any directory that appears in the results, and any subdirectory of that directory. Ensure that the NFS export is accessible without Kerberos authentication.  To transfer all the data in the folder that you specified, DataSync must have permissions to read all the data. To ensure this, either configure the NFS export with no_root_squash, or ensure that the files you want DataSync to access have permissions that allow read access for all users. Doing either option enables the agent to read the files. For the agent to access directories, you must additionally enable all execute access. If you are copying data to or from your AWS Snowcone device, see NFS Server on AWS Snowcone for more information. For information about NFS export configuration, see 18.7. The /etc/exports Configuration File in the Red Hat Enterprise Linux documentation. Defaults to None.
        on_prem_config(Dict, optional): A list of Amazon Resource Names (ARNs) of agents to use for a Network File System (NFS) location. Defaults to None.
        mount_options(Dict, optional): Represents the mount options that are available for DataSync to access an NFS location. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datasync.location.nf.update_multiple(ctx, location_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datasync.location.nf.update_multiple location_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datasync",
        operation="update_location_nfs",
        op_kwargs={
            "LocationArn": location_arn,
            "Subdirectory": subdirectory,
            "OnPremConfig": on_prem_config,
            "MountOptions": mount_options,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    configuration_aggregator_name: str,
    filters: Dict = None,
    limit: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of the conformance packs and their associated compliance status with the count of compliant and noncompliant AWS Config rules within each conformance pack. Also returns the total rule count which includes compliant rules, noncompliant rules, and rules that cannot be evaluated due to insufficient data.  The results can return an empty result page, but if you have a nextToken, the results are displayed on the next page.

    Args:
        configuration_aggregator_name(str): The name of the configuration aggregator.
        filters(Dict, optional): Filters the result by AggregateConformancePackComplianceFilters object. Defaults to None.
        limit(int, optional): The maximum number of conformance packs compliance details returned on each page. The default is maximum. If you specify 0, AWS Config uses the default. . Defaults to None.
        next_token(str, optional): The nextToken string returned on a previous page that you use to get the next page of results in a paginated response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.aggregate.compliance.by.conformance_pack.describe_all(
                ctx, configuration_aggregator_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.aggregate.compliance.by.conformance_pack.describe_all configuration_aggregator_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="describe_aggregate_compliance_by_conformance_packs",
        op_kwargs={
            "ConfigurationAggregatorName": configuration_aggregator_name,
            "Filters": filters,
            "Limit": limit,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the LoggingConfiguration from the specified web ACL.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the web ACL from which you want to delete the LoggingConfiguration.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.logging_configuration.delete(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.logging_configuration.delete resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="delete_logging_configuration",
        op_kwargs={"ResourceArn": resource_arn},
    )


async def get(hub, ctx, resource_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the LoggingConfiguration for the specified web ACL.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the web ACL for which you want to get the LoggingConfiguration.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.logging_configuration.get(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.logging_configuration.get resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="get_logging_configuration",
        op_kwargs={"ResourceArn": resource_arn},
    )


async def list_all(
    hub, ctx, scope: str = None, next_marker: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves an array of your LoggingConfiguration objects.

    Args:
        scope(str, optional): Specifies whether this is for an Amazon CloudFront distribution or for a regional application. A regional application can be an Application Load Balancer (ALB), an Amazon API Gateway REST API, or an AppSync GraphQL API.  To work with CloudFront, you must also specify the Region US East (N. Virginia) as follows:    CLI - Specify the Region when you use the CloudFront scope: --scope=CLOUDFRONT --region=us-east-1.    API and SDKs - For all calls, use the Region endpoint us-east-1.   . Defaults to None.
        next_marker(str, optional): When you request a list of objects with a Limit setting, if the number of objects that are still available for retrieval exceeds the limit, WAF returns a NextMarker value in the response. To retrieve the next batch of objects, provide the marker from the prior call in your next request. Defaults to None.
        limit(int, optional): The maximum number of objects that you want WAF to return for this request. If more objects are available, in the response, WAF provides a NextMarker value that you can use in a subsequent call to get the next batch of objects. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.logging_configuration.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.logging_configuration.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="list_logging_configurations",
        op_kwargs={"Scope": scope, "NextMarker": next_marker, "Limit": limit},
    )


async def put(hub, ctx, logging_configuration: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Enables the specified LoggingConfiguration, to start logging from a web ACL, according to the configuration provided. You can access information about all traffic that WAF inspects using the following steps:   Create an Amazon Kinesis Data Firehose.  Create the data firehose with a PUT source and in the Region that you are operating. If you are capturing logs for Amazon CloudFront, always create the firehose in US East (N. Virginia).  Give the data firehose a name that starts with the prefix aws-waf-logs-. For example, aws-waf-logs-us-east-2-analytics.  Do not create the data firehose using a Kinesis stream as your source.    Associate that firehose to your web ACL using a PutLoggingConfiguration request.   When you successfully enable logging using a PutLoggingConfiguration request, WAF will create a service linked role with the necessary permissions to write logs to the Amazon Kinesis Data Firehose. For more information, see Logging Web ACL Traffic Information in the WAF Developer Guide.  This operation completely replaces the mutable specifications that you already have for the logging configuration with the ones that you provide to this call. To modify the logging configuration, retrieve it by calling GetLoggingConfiguration, update the settings as needed, and then provide the complete logging configuration specification to this call.

    Args:
        logging_configuration(Dict): .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wafv2.logging_configuration.put(
                ctx, logging_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wafv2.logging_configuration.put logging_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wafv2",
        operation="put_logging_configuration",
        op_kwargs={"LoggingConfiguration": logging_configuration},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"list_": "list"}


async def list_(
    hub, ctx, index_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the Amazon Kendra thesauri associated with an index.

    Args:
        index_id(str): The identifier of the index associated with the thesaurus to list.
        next_token(str, optional): If the previous response was incomplete (because there is more data to retrieve), Amazon Kendra returns a pagination token in the response. You can use this pagination token to retrieve the next set of thesauri (ThesaurusSummaryItems). . Defaults to None.
        max_results(int, optional): The maximum number of thesauri to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kendra.thesauri.list(ctx, index_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kendra.thesauri.list index_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kendra",
        operation="list_thesauri",
        op_kwargs={
            "IndexId": index_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, user_name: str, service_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Generates a set of credentials consisting of a user name and password that can be used to access the service specified in the request. These credentials are generated by IAM, and can be used only for the specified service.  You can have a maximum of two sets of service-specific credentials for each supported service per user. You can create service-specific credentials for CodeCommit and Amazon Keyspaces (for Apache Cassandra). You can reset the password to a new service-generated value by calling ResetServiceSpecificCredential. For more information about service-specific credentials, see Using IAM with CodeCommit: Git credentials, SSH keys, and Amazon Web Services access keys in the IAM User Guide.

    Args:
        user_name(str): The name of the IAM user that is to be associated with the credentials. The new service-specific credentials have the same permissions as the associated user except that they can be used only to access the specified service. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-.
        service_name(str): The name of the Amazon Web Services service that is to be associated with the credentials. The service you specify here is the only service that can be accessed using these credentials.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.service.specific_credential.create(
                ctx, user_name=value, service_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.service.specific_credential.create user_name=value, service_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="create_service_specific_credential",
        op_kwargs={"UserName": user_name, "ServiceName": service_name},
    )


async def delete(
    hub, ctx, service_specific_credential_id: str, user_name: str = None
) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified service-specific credential.

    Args:
        user_name(str, optional): The name of the IAM user associated with the service-specific credential. If this value is not specified, then the operation assumes the user whose credentials are used to call the operation. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-. Defaults to None.
        service_specific_credential_id(str): The unique identifier of the service-specific credential. You can get this value by calling ListServiceSpecificCredentials. This parameter allows (through its regex pattern) a string of characters that can consist of any upper or lowercased letter or digit.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.service.specific_credential.delete(
                ctx, service_specific_credential_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.service.specific_credential.delete service_specific_credential_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="delete_service_specific_credential",
        op_kwargs={
            "UserName": user_name,
            "ServiceSpecificCredentialId": service_specific_credential_id,
        },
    )


async def list_all(hub, ctx, user_name: str = None, service_name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns information about the service-specific credentials associated with the specified IAM user. If none exists, the operation returns an empty list. The service-specific credentials returned by this operation are used only for authenticating the IAM user to a specific service. For more information about using service-specific credentials to authenticate to an Amazon Web Services service, see Set up service-specific credentials in the CodeCommit User Guide.

    Args:
        user_name(str, optional): The name of the user whose service-specific credentials you want information about. If this value is not specified, then the operation assumes the user whose credentials are used to call the operation. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-. Defaults to None.
        service_name(str, optional): Filters the returned results to only those for the specified Amazon Web Services service. If not specified, then Amazon Web Services returns service-specific credentials for all services. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.service.specific_credential.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.service.specific_credential.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="list_service_specific_credentials",
        op_kwargs={"UserName": user_name, "ServiceName": service_name},
    )


async def reset(
    hub, ctx, service_specific_credential_id: str, user_name: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Resets the password for a service-specific credential. The new password is Amazon Web Services generated and cryptographically strong. It cannot be configured by the user. Resetting the password immediately invalidates the previous password associated with this user.

    Args:
        user_name(str, optional): The name of the IAM user associated with the service-specific credential. If this value is not specified, then the operation assumes the user whose credentials are used to call the operation. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-. Defaults to None.
        service_specific_credential_id(str): The unique identifier of the service-specific credential. This parameter allows (through its regex pattern) a string of characters that can consist of any upper or lowercased letter or digit.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.service.specific_credential.reset(
                ctx, service_specific_credential_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.service.specific_credential.reset service_specific_credential_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="reset_service_specific_credential",
        op_kwargs={
            "UserName": user_name,
            "ServiceSpecificCredentialId": service_specific_credential_id,
        },
    )


async def update(
    hub, ctx, service_specific_credential_id: str, status: str, user_name: str = None
) -> None:
    r"""
    **Autogenerated function**

    Sets the status of a service-specific credential to Active or Inactive. Service-specific credentials that are inactive cannot be used for authentication to the service. This operation can be used to disable a user's service-specific credential as part of a credential rotation work flow.

    Args:
        user_name(str, optional): The name of the IAM user associated with the service-specific credential. If you do not specify this value, then the operation assumes the user whose credentials are used to call the operation. This parameter allows (through its regex pattern) a string of characters consisting of upper and lowercase alphanumeric characters with no spaces. You can also include any of the following characters: _+=,.@-. Defaults to None.
        service_specific_credential_id(str): The unique identifier of the service-specific credential. This parameter allows (through its regex pattern) a string of characters that can consist of any upper or lowercased letter or digit.
        status(str): The status to be assigned to the service-specific credential.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iam.service.specific_credential.update(
                ctx, service_specific_credential_id=value, status=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iam.service.specific_credential.update service_specific_credential_id=value, status=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iam",
        operation="update_service_specific_credential",
        op_kwargs={
            "UserName": user_name,
            "ServiceSpecificCredentialId": service_specific_credential_id,
            "Status": status,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Provides the details for the Security Hub administrator account for the current member account. Can be used by both member accounts that are managed using Organizations and accounts that were invited manually.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.securityhub.administrator.account.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.securityhub.administrator.account.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="securityhub",
        operation="get_administrator_account",
        op_kwargs={},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx, suite_definition_id: str, suite_run_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a Device Advisor test suite run.

    Args:
        suite_definition_id(str): Suite definition Id for the test suite run.
        suite_run_id(str): Suite run Id for the test suite run.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotdeviceadvisor.suite.run.init.get(
                ctx, suite_definition_id=value, suite_run_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotdeviceadvisor.suite.run.init.get suite_definition_id=value, suite_run_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotdeviceadvisor",
        operation="get_suite_run",
        op_kwargs={
            "suiteDefinitionId": suite_definition_id,
            "suiteRunId": suite_run_id,
        },
    )


async def list_all(
    hub,
    ctx,
    suite_definition_id: str = None,
    suite_definition_version: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the runs of the specified Device Advisor test suite. You can list all runs of the test suite, or the runs of a specific version of the test suite.

    Args:
        suite_definition_id(str, optional): Lists the test suite runs of the specified test suite based on suite definition Id. Defaults to None.
        suite_definition_version(str, optional): Must be passed along with suiteDefinitionId. Lists the test suite runs of the specified test suite based on suite definition version. Defaults to None.
        max_results(int, optional): The maximum number of results to return at once. Defaults to None.
        next_token(str, optional): A token to retrieve the next set of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotdeviceadvisor.suite.run.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotdeviceadvisor.suite.run.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotdeviceadvisor",
        operation="list_suite_runs",
        op_kwargs={
            "suiteDefinitionId": suite_definition_id,
            "suiteDefinitionVersion": suite_definition_version,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )


async def start(
    hub,
    ctx,
    suite_definition_id: str,
    suite_definition_version: str = None,
    suite_run_configuration: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts a Device Advisor test suite run.

    Args:
        suite_definition_id(str): Suite definition Id of the test suite.
        suite_definition_version(str, optional): Suite definition version of the test suite. Defaults to None.
        suite_run_configuration(Dict, optional): Suite run configuration. Defaults to None.
        tags(Dict, optional): The tags to be attached to the suite run. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotdeviceadvisor.suite.run.init.start(
                ctx, suite_definition_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotdeviceadvisor.suite.run.init.start suite_definition_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotdeviceadvisor",
        operation="start_suite_run",
        op_kwargs={
            "suiteDefinitionId": suite_definition_id,
            "suiteDefinitionVersion": suite_definition_version,
            "suiteRunConfiguration": suite_run_configuration,
            "tags": tags,
        },
    )


async def stop(hub, ctx, suite_definition_id: str, suite_run_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Stops a Device Advisor test suite run that is currently running.

    Args:
        suite_definition_id(str): Suite definition Id of the test suite run to be stopped.
        suite_run_id(str): Suite run Id of the test suite run to be stopped.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iotdeviceadvisor.suite.run.init.stop(
                ctx, suite_definition_id=value, suite_run_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iotdeviceadvisor.suite.run.init.stop suite_definition_id=value, suite_run_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iotdeviceadvisor",
        operation="stop_suite_run",
        op_kwargs={
            "suiteDefinitionId": suite_definition_id,
            "suiteRunId": suite_run_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    description: str = None,
    repository: str = None,
    platform: str = None,
    iam_service_role_arn: str = None,
    oauth_token: str = None,
    access_token: str = None,
    environment_variables: Dict = None,
    enable_branch_auto_build: bool = None,
    enable_branch_auto_deletion: bool = None,
    enable_basic_auth: bool = None,
    basic_auth_credentials: str = None,
    custom_rules: List = None,
    tags: Dict = None,
    build_spec: str = None,
    custom_headers: str = None,
    enable_auto_branch_creation: bool = None,
    auto_branch_creation_patterns: List = None,
    auto_branch_creation_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Creates a new Amplify app.

    Args:
        name(str):  The name for an Amplify app. .
        description(str, optional):  The description for an Amplify app. . Defaults to None.
        repository(str, optional):  The repository for an Amplify app. . Defaults to None.
        platform(str, optional):  The platform or framework for an Amplify app. . Defaults to None.
        iam_service_role_arn(str, optional):  The AWS Identity and Access Management (IAM) service role for an Amplify app. . Defaults to None.
        oauth_token(str, optional):  The OAuth token for a third-party source control system for an Amplify app. The OAuth token is used to create a webhook and a read-only deploy key. The OAuth token is not stored. . Defaults to None.
        access_token(str, optional):  The personal access token for a third-party source control system for an Amplify app. The personal access token is used to create a webhook and a read-only deploy key. The token is not stored. . Defaults to None.
        environment_variables(Dict, optional):  The environment variables map for an Amplify app. . Defaults to None.
        enable_branch_auto_build(bool, optional):  Enables the auto building of branches for an Amplify app. . Defaults to None.
        enable_branch_auto_deletion(bool, optional):  Automatically disconnects a branch in the Amplify Console when you delete a branch from your Git repository. . Defaults to None.
        enable_basic_auth(bool, optional):  Enables basic authorization for an Amplify app. This will apply to all branches that are part of this app. . Defaults to None.
        basic_auth_credentials(str, optional):  The credentials for basic authorization for an Amplify app. . Defaults to None.
        custom_rules(List, optional):  The custom rewrite and redirect rules for an Amplify app. . Defaults to None.
        tags(Dict, optional):  The tag for an Amplify app. . Defaults to None.
        build_spec(str, optional):  The build specification (build spec) for an Amplify app. . Defaults to None.
        custom_headers(str, optional): The custom HTTP headers for an Amplify app. Defaults to None.
        enable_auto_branch_creation(bool, optional):  Enables automated branch creation for an Amplify app. . Defaults to None.
        auto_branch_creation_patterns(List, optional):  The automated branch creation glob patterns for an Amplify app. . Defaults to None.
        auto_branch_creation_config(Dict, optional):  The automated branch creation configuration for an Amplify app. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplify.app.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplify.app.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplify",
        operation="create_app",
        op_kwargs={
            "name": name,
            "description": description,
            "repository": repository,
            "platform": platform,
            "iamServiceRoleArn": iam_service_role_arn,
            "oauthToken": oauth_token,
            "accessToken": access_token,
            "environmentVariables": environment_variables,
            "enableBranchAutoBuild": enable_branch_auto_build,
            "enableBranchAutoDeletion": enable_branch_auto_deletion,
            "enableBasicAuth": enable_basic_auth,
            "basicAuthCredentials": basic_auth_credentials,
            "customRules": custom_rules,
            "tags": tags,
            "buildSpec": build_spec,
            "customHeaders": custom_headers,
            "enableAutoBranchCreation": enable_auto_branch_creation,
            "autoBranchCreationPatterns": auto_branch_creation_patterns,
            "autoBranchCreationConfig": auto_branch_creation_config,
        },
    )


async def delete(hub, ctx, app_id: str) -> Dict:
    r"""
    **Autogenerated function**

     Deletes an existing Amplify app specified by an app ID.

    Args:
        app_id(str):  The unique ID for an Amplify app. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplify.app.delete(ctx, app_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplify.app.delete app_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="amplify", operation="delete_app", op_kwargs={"appId": app_id}
    )


async def get(hub, ctx, app_id: str) -> Dict:
    r"""
    **Autogenerated function**

     Returns an existing Amplify app by appID.

    Args:
        app_id(str):  The unique ID for an Amplify app. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplify.app.get(ctx, app_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplify.app.get app_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="amplify", operation="get_app", op_kwargs={"appId": app_id}
    )


async def update(
    hub,
    ctx,
    app_id: str,
    name: str = None,
    description: str = None,
    platform: str = None,
    iam_service_role_arn: str = None,
    environment_variables: Dict = None,
    enable_branch_auto_build: bool = None,
    enable_branch_auto_deletion: bool = None,
    enable_basic_auth: bool = None,
    basic_auth_credentials: str = None,
    custom_rules: List = None,
    build_spec: str = None,
    custom_headers: str = None,
    enable_auto_branch_creation: bool = None,
    auto_branch_creation_patterns: List = None,
    auto_branch_creation_config: Dict = None,
    repository: str = None,
    oauth_token: str = None,
    access_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Updates an existing Amplify app.

    Args:
        app_id(str):  The unique ID for an Amplify app. .
        name(str, optional):  The name for an Amplify app. . Defaults to None.
        description(str, optional):  The description for an Amplify app. . Defaults to None.
        platform(str, optional):  The platform for an Amplify app. . Defaults to None.
        iam_service_role_arn(str, optional):  The AWS Identity and Access Management (IAM) service role for an Amplify app. . Defaults to None.
        environment_variables(Dict, optional):  The environment variables for an Amplify app. . Defaults to None.
        enable_branch_auto_build(bool, optional):  Enables branch auto-building for an Amplify app. . Defaults to None.
        enable_branch_auto_deletion(bool, optional):  Automatically disconnects a branch in the Amplify Console when you delete a branch from your Git repository. . Defaults to None.
        enable_basic_auth(bool, optional):  Enables basic authorization for an Amplify app. . Defaults to None.
        basic_auth_credentials(str, optional):  The basic authorization credentials for an Amplify app. . Defaults to None.
        custom_rules(List, optional):  The custom redirect and rewrite rules for an Amplify app. . Defaults to None.
        build_spec(str, optional):  The build specification (build spec) for an Amplify app. . Defaults to None.
        custom_headers(str, optional): The custom HTTP headers for an Amplify app. Defaults to None.
        enable_auto_branch_creation(bool, optional):  Enables automated branch creation for an Amplify app. . Defaults to None.
        auto_branch_creation_patterns(List, optional):  Describes the automated branch creation glob patterns for an Amplify app. . Defaults to None.
        auto_branch_creation_config(Dict, optional):  The automated branch creation configuration for an Amplify app. . Defaults to None.
        repository(str, optional):  The name of the repository for an Amplify app . Defaults to None.
        oauth_token(str, optional):  The OAuth token for a third-party source control system for an Amplify app. The token is used to create a webhook and a read-only deploy key. The OAuth token is not stored. . Defaults to None.
        access_token(str, optional):  The personal access token for a third-party source control system for an Amplify app. The token is used to create webhook and a read-only deploy key. The token is not stored. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplify.app.update(ctx, app_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplify.app.update app_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplify",
        operation="update_app",
        op_kwargs={
            "appId": app_id,
            "name": name,
            "description": description,
            "platform": platform,
            "iamServiceRoleArn": iam_service_role_arn,
            "environmentVariables": environment_variables,
            "enableBranchAutoBuild": enable_branch_auto_build,
            "enableBranchAutoDeletion": enable_branch_auto_deletion,
            "enableBasicAuth": enable_basic_auth,
            "basicAuthCredentials": basic_auth_credentials,
            "customRules": custom_rules,
            "buildSpec": build_spec,
            "customHeaders": custom_headers,
            "enableAutoBranchCreation": enable_auto_branch_creation,
            "autoBranchCreationPatterns": auto_branch_creation_patterns,
            "autoBranchCreationConfig": auto_branch_creation_config,
            "repository": repository,
            "oauthToken": oauth_token,
            "accessToken": access_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def associate(
    hub,
    ctx,
    instance_event_window_id: str,
    association_target: Dict,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Associates one or more targets with an event window. Only one type of target (instance IDs, Dedicated Host IDs, or tags) can be specified with an event window. For more information, see Define event windows for scheduled events in the Amazon EC2 User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        instance_event_window_id(str): The ID of the event window.
        association_target(Dict): One or more targets associated with the specified event window.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.event.window.associate(
                ctx, instance_event_window_id=value, association_target=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.event.window.associate instance_event_window_id=value, association_target=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="associate_instance_event_window",
        op_kwargs={
            "DryRun": dry_run,
            "InstanceEventWindowId": instance_event_window_id,
            "AssociationTarget": association_target,
        },
    )


async def create(
    hub,
    ctx,
    dry_run: bool = None,
    name: str = None,
    time_ranges: List = None,
    cron_expression: str = None,
    tag_specifications: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an event window in which scheduled events for the associated Amazon EC2 instances can run. You can define either a set of time ranges or a cron expression when creating the event window, but not both. All event window times are in UTC. You can create up to 200 event windows per Amazon Web Services Region. When you create the event window, targets (instance IDs, Dedicated Host IDs, or tags) are not yet associated with it. To ensure that the event window can be used, you must associate one or more targets with it by using the AssociateInstanceEventWindow API.  Event windows are applicable only for scheduled events that stop, reboot, or terminate instances. Event windows are not applicable for:   Expedited scheduled events and network maintenance events.    Unscheduled maintenance such as AutoRecovery and unplanned reboots.    For more information, see Define event windows for scheduled events in the Amazon EC2 User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        name(str, optional): The name of the event window. Defaults to None.
        time_ranges(List, optional): The time range for the event window. If you specify a time range, you can't specify a cron expression. Defaults to None.
        cron_expression(str, optional): The cron expression for the event window, for example, * 0-4,20-23 * * 1,5. If you specify a cron expression, you can't specify a time range. Constraints:   Only hour and day of the week values are supported.   For day of the week values, you can specify either integers 0 through 6, or alternative single values SUN through SAT.   The minute, month, and year must be specified by *.   The hour value must be one or a multiple range, for example, 0-4 or 0-4,20-23.   Each hour range must be >= 2 hours, for example, 0-2 or 20-23.   The event window must be >= 4 hours. The combined total time ranges in the event window must be >= 4 hours.   For more information about cron expressions, see cron on the Wikipedia website. Defaults to None.
        tag_specifications(List, optional): The tags to apply to the event window. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.event.window.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.event.window.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_instance_event_window",
        op_kwargs={
            "DryRun": dry_run,
            "Name": name,
            "TimeRanges": time_ranges,
            "CronExpression": cron_expression,
            "TagSpecifications": tag_specifications,
        },
    )


async def delete(
    hub,
    ctx,
    instance_event_window_id: str,
    dry_run: bool = None,
    force_delete: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified event window. For more information, see Define event windows for scheduled events in the Amazon EC2 User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        force_delete(bool, optional): Specify true to force delete the event window. Use the force delete parameter if the event window is currently associated with targets. Defaults to None.
        instance_event_window_id(str): The ID of the event window.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.event.window.delete(
                ctx, instance_event_window_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.event.window.delete instance_event_window_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_instance_event_window",
        op_kwargs={
            "DryRun": dry_run,
            "ForceDelete": force_delete,
            "InstanceEventWindowId": instance_event_window_id,
        },
    )


async def describe_all(
    hub,
    ctx,
    dry_run: bool = None,
    instance_event_window_ids: List = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified event windows or all event windows. If you specify event window IDs, the output includes information for only the specified event windows. If you specify filters, the output includes information for only those event windows that meet the filter criteria. If you do not specify event windows IDs or filters, the output includes information for all event windows, which can affect performance. We recommend that you use pagination to ensure that the operation returns quickly and successfully.  For more information, see Define event windows for scheduled events in the Amazon EC2 User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        instance_event_window_ids(List, optional): The IDs of the event windows. Defaults to None.
        filters(List, optional): One or more filters.    dedicated-host-id - The event windows associated with the specified Dedicated Host ID.    event-window-name - The event windows associated with the specified names.     instance-id - The event windows associated with the specified instance ID.    instance-tag - The event windows associated with the specified tag and value.    instance-tag-key - The event windows associated with the specified tag key, regardless of the value.    instance-tag-value - The event windows associated with the specified tag value, regardless of the key.    tag:<key> - The key/value combination of a tag assigned to the event window. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value CMX, specify tag:Owner for the filter name and CMX for the filter value.     tag-key - The key of a tag assigned to the event window. Use this filter to find all event windows that have a tag with a specific key, regardless of the tag value.     tag-value - The value of a tag assigned to the event window. Use this filter to find all event windows that have a tag with a specific value, regardless of the tag key.   . Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. To retrieve the remaining results, make another call with the returned NextToken value. This value can be between 20 and 500. You cannot specify this parameter and the event window IDs parameter in the same call. Defaults to None.
        next_token(str, optional): The token to request the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.event.window.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.event.window.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_instance_event_windows",
        op_kwargs={
            "DryRun": dry_run,
            "InstanceEventWindowIds": instance_event_window_ids,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )


async def disassociate(
    hub,
    ctx,
    instance_event_window_id: str,
    association_target: Dict,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates one or more targets from an event window. For more information, see Define event windows for scheduled events in the Amazon EC2 User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        instance_event_window_id(str): The ID of the event window.
        association_target(Dict): One or more targets to disassociate from the specified event window.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.event.window.disassociate(
                ctx, instance_event_window_id=value, association_target=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.event.window.disassociate instance_event_window_id=value, association_target=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="disassociate_instance_event_window",
        op_kwargs={
            "DryRun": dry_run,
            "InstanceEventWindowId": instance_event_window_id,
            "AssociationTarget": association_target,
        },
    )


async def modify(
    hub,
    ctx,
    instance_event_window_id: str,
    dry_run: bool = None,
    name: str = None,
    time_ranges: List = None,
    cron_expression: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the specified event window. You can define either a set of time ranges or a cron expression when modifying the event window, but not both. To modify the targets associated with the event window, use the AssociateInstanceEventWindow and DisassociateInstanceEventWindow API. If Amazon Web Services has already scheduled an event, modifying an event window won't change the time of the scheduled event. For more information, see Define event windows for scheduled events in the Amazon EC2 User Guide.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        name(str, optional): The name of the event window. Defaults to None.
        instance_event_window_id(str): The ID of the event window.
        time_ranges(List, optional): The time ranges of the event window. Defaults to None.
        cron_expression(str, optional): The cron expression of the event window, for example, * 0-4,20-23 * * 1,5. Constraints:   Only hour and day of the week values are supported.   For day of the week values, you can specify either integers 0 through 6, or alternative single values SUN through SAT.   The minute, month, and year must be specified by *.   The hour value must be one or a multiple range, for example, 0-4 or 0-4,20-23.   Each hour range must be >= 2 hours, for example, 0-2 or 20-23.   The event window must be >= 4 hours. The combined total time ranges in the event window must be >= 4 hours.   For more information about cron expressions, see cron on the Wikipedia website. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.instance.event.window.modify(
                ctx, instance_event_window_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.instance.event.window.modify instance_event_window_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_instance_event_window",
        op_kwargs={
            "DryRun": dry_run,
            "Name": name,
            "InstanceEventWindowId": instance_event_window_id,
            "TimeRanges": time_ranges,
            "CronExpression": cron_expression,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, token_name: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a GitHub account connection.

    Args:
        token_name(str, optional): The name of the GitHub account connection to delete. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codedeploy.git_hub_account_token.init.delete(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codedeploy.git_hub_account_token.init.delete
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codedeploy",
        operation="delete_git_hub_account_token",
        op_kwargs={"tokenName": token_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def deregister(hub, ctx, service_id: str, instance_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the Amazon Route 53 DNS records and health check, if any, that Cloud Map created for the specified instance.

    Args:
        service_id(str): The ID of the service that the instance is associated with.
        instance_id(str): The value that you specified for Id in the RegisterInstance request.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicediscovery.instance.init.deregister(
                ctx, service_id=value, instance_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicediscovery.instance.init.deregister service_id=value, instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicediscovery",
        operation="deregister_instance",
        op_kwargs={"ServiceId": service_id, "InstanceId": instance_id},
    )


async def discover(
    hub,
    ctx,
    namespace_name: str,
    service_name: str,
    max_results: int = None,
    query_parameters: Dict = None,
    optional_parameters: Dict = None,
    health_status: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Discovers registered instances for a specified namespace and service. You can use DiscoverInstances to discover instances for any type of namespace. For public and private DNS namespaces, you can also use DNS queries to discover instances.

    Args:
        namespace_name(str): The HttpName name of the namespace. It's found in the HttpProperties member of the Properties member of the namespace.
        service_name(str): The name of the service that you specified when you registered the instance.
        max_results(int, optional): The maximum number of instances that you want Cloud Map to return in the response to a DiscoverInstances request. If you don't specify a value for MaxResults, Cloud Map returns up to 100 instances. Defaults to None.
        query_parameters(Dict, optional): Filters to scope the results based on custom attributes for the instance (for example, {version=v1, az=1a}). Only instances that match all the specified key-value pairs are returned. Defaults to None.
        optional_parameters(Dict, optional): Opportunistic filters to scope the results based on custom attributes. If there are instances that match both the filters specified in both the QueryParameters parameter and this parameter, all of these instances are returned. Otherwise, the filters are ignored, and only instances that match the filters that are specified in the QueryParameters parameter are returned. Defaults to None.
        health_status(str, optional): The health status of the instances that you want to discover. This parameter is ignored for services that don't have a health check configured, and all instances are returned.  HEALTHY  Returns healthy instances.  UNHEALTHY  Returns unhealthy instances.  ALL  Returns all instances.  HEALTHY_OR_ELSE_ALL  Returns healthy instances, unless none are reporting a healthy state. In that case, return all instances. This is also called failing open.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicediscovery.instance.init.discover(
                ctx, namespace_name=value, service_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicediscovery.instance.init.discover namespace_name=value, service_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicediscovery",
        operation="discover_instances",
        op_kwargs={
            "NamespaceName": namespace_name,
            "ServiceName": service_name,
            "MaxResults": max_results,
            "QueryParameters": query_parameters,
            "OptionalParameters": optional_parameters,
            "HealthStatus": health_status,
        },
    )


async def get(hub, ctx, service_id: str, instance_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a specified instance.

    Args:
        service_id(str): The ID of the service that the instance is associated with.
        instance_id(str): The ID of the instance that you want to get information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicediscovery.instance.init.get(
                ctx, service_id=value, instance_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicediscovery.instance.init.get service_id=value, instance_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicediscovery",
        operation="get_instance",
        op_kwargs={"ServiceId": service_id, "InstanceId": instance_id},
    )


async def list_all(
    hub, ctx, service_id: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists summary information about the instances that you registered by using a specified service.

    Args:
        service_id(str): The ID of the service that you want to list instances for.
        next_token(str, optional): For the first ListInstances request, omit this value. If more than MaxResults instances match the specified criteria, you can submit another ListInstances request to get the next group of results. Specify the value of NextToken from the previous response in the next request. Defaults to None.
        max_results(int, optional): The maximum number of instances that you want Cloud Map to return in the response to a ListInstances request. If you don't specify a value for MaxResults, Cloud Map returns up to 100 instances. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicediscovery.instance.init.list_all(ctx, service_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicediscovery.instance.init.list_all service_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicediscovery",
        operation="list_instances",
        op_kwargs={
            "ServiceId": service_id,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def register(
    hub,
    ctx,
    service_id: str,
    instance_id: str,
    attributes: Dict,
    creator_request_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates or updates one or more records and, optionally, creates a health check based on the settings in a specified service. When you submit a RegisterInstance request, the following occurs:   For each DNS record that you define in the service that's specified by ServiceId, a record is created or updated in the hosted zone that's associated with the corresponding namespace.   If the service includes HealthCheckConfig, a health check is created based on the settings in the health check configuration.   The health check, if any, is associated with each of the new or updated records.    One RegisterInstance request must complete before you can submit another request and specify the same service ID and instance ID.  For more information, see CreateService. When Cloud Map receives a DNS query for the specified DNS name, it returns the applicable value:    If the health check is healthy: returns all the records    If the health check is unhealthy: returns the applicable value for the last healthy instance    If you didn't specify a health check configuration: returns all the records   For the current quota on the number of instances that you can register using the same namespace and using the same service, see Cloud Map quotas in the Cloud Map Developer Guide.

    Args:
        service_id(str): The ID of the service that you want to use for settings for the instance.
        instance_id(str): An identifier that you want to associate with the instance. Note the following:   If the service that's specified by ServiceId includes settings for an SRV record, the value of InstanceId is automatically included as part of the value for the SRV record. For more information, see DnsRecord > Type.   You can use this value to update an existing instance.   To register a new instance, you must specify a value that's unique among instances that you register by using the same service.    If you specify an existing InstanceId and ServiceId, Cloud Map updates the existing DNS records, if any. If there's also an existing health check, Cloud Map deletes the old health check and creates a new one.   The health check isn't deleted immediately, so it will still appear for a while if you submit a ListHealthChecks request, for example.   .
        creator_request_id(str, optional): A unique string that identifies the request and that allows failed RegisterInstance requests to be retried without the risk of executing the operation twice. You must use a unique CreatorRequestId string every time you submit a RegisterInstance request if you're registering additional instances for the same namespace and service. CreatorRequestId can be any unique string (for example, a date/time stamp). Defaults to None.
        attributes(Dict): A string map that contains the following information for the service that you specify in ServiceId:   The attributes that apply to the records that are defined in the service.    For each attribute, the applicable value.   Supported attribute keys include the following:  AWS_ALIAS_DNS_NAME  If you want Cloud Map to create an Amazon Route 53 alias record that routes traffic to an Elastic Load Balancing load balancer, specify the DNS name that's associated with the load balancer. For information about how to get the DNS name, see "DNSName" in the topic AliasTarget in the Route 53 API Reference. Note the following:   The configuration for the service that's specified by ServiceId must include settings for an A record, an AAAA record, or both.   In the service that's specified by ServiceId, the value of RoutingPolicy must be WEIGHTED.   If the service that's specified by ServiceId includes HealthCheckConfig settings, Cloud Map will create the Route 53 health check, but it doesn't associate the health check with the alias record.   Auto naming currently doesn't support creating alias records that route traffic to Amazon Web Services resources other than Elastic Load Balancing load balancers.   If you specify a value for AWS_ALIAS_DNS_NAME, don't specify values for any of the AWS_INSTANCE attributes.    AWS_EC2_INSTANCE_ID   HTTP namespaces only. The Amazon EC2 instance ID for the instance. If the AWS_EC2_INSTANCE_ID attribute is specified, then the only other attribute that can be specified is AWS_INIT_HEALTH_STATUS. When the AWS_EC2_INSTANCE_ID attribute is specified, then the AWS_INSTANCE_IPV4 attribute will be filled out with the primary private IPv4 address.  AWS_INIT_HEALTH_STATUS  If the service configuration includes HealthCheckCustomConfig, you can optionally use AWS_INIT_HEALTH_STATUS to specify the initial status of the custom health check, HEALTHY or UNHEALTHY. If you don't specify a value for AWS_INIT_HEALTH_STATUS, the initial status is HEALTHY.  AWS_INSTANCE_CNAME  If the service configuration includes a CNAME record, the domain name that you want Route 53 to return in response to DNS queries (for example, example.com). This value is required if the service specified by ServiceId includes settings for an CNAME record.  AWS_INSTANCE_IPV4  If the service configuration includes an A record, the IPv4 address that you want Route 53 to return in response to DNS queries (for example, 192.0.2.44). This value is required if the service specified by ServiceId includes settings for an A record. If the service includes settings for an SRV record, you must specify a value for AWS_INSTANCE_IPV4, AWS_INSTANCE_IPV6, or both.  AWS_INSTANCE_IPV6  If the service configuration includes an AAAA record, the IPv6 address that you want Route 53 to return in response to DNS queries (for example, 2001:0db8:85a3:0000:0000:abcd:0001:2345). This value is required if the service specified by ServiceId includes settings for an AAAA record. If the service includes settings for an SRV record, you must specify a value for AWS_INSTANCE_IPV4, AWS_INSTANCE_IPV6, or both.  AWS_INSTANCE_PORT  If the service includes an SRV record, the value that you want Route 53 to return for the port. If the service includes HealthCheckConfig, the port on the endpoint that you want Route 53 to send requests to.  This value is required if you specified settings for an SRV record or a Route 53 health check when you created the service.  Custom attributes  You can add up to 30 custom attributes. For each key-value pair, the maximum length of the attribute name is 255 characters, and the maximum length of the attribute value is 1,024 characters. The total size of all provided attributes (sum of all keys and values) must not exceed 5,000 characters.  .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicediscovery.instance.init.register(
                ctx, service_id=value, instance_id=value, attributes=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicediscovery.instance.init.register service_id=value, instance_id=value, attributes=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicediscovery",
        operation="register_instance",
        op_kwargs={
            "ServiceId": service_id,
            "InstanceId": instance_id,
            "CreatorRequestId": creator_request_id,
            "Attributes": attributes,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def associate(
    hub, ctx, service_arn: str, domain_name: str, enable_www_subdomain: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Associate your own domain name with the AWS App Runner subdomain URL of your App Runner service. After you call AssociateCustomDomain and receive a successful response, use the information in the CustomDomain record that's returned to add CNAME records to your Domain Name System (DNS). For each mapped domain name, add a mapping to the target App Runner subdomain and one or more certificate validation records. App Runner then performs DNS validation to verify that you own or control the domain name that you associated. App Runner tracks domain validity in a certificate stored in AWS Certificate Manager (ACM).

    Args:
        service_arn(str): The Amazon Resource Name (ARN) of the App Runner service that you want to associate a custom domain name with.
        domain_name(str): A custom domain endpoint to associate. Specify a root domain (for example, example.com), a subdomain (for example, login.example.com or admin.login.example.com), or a wildcard (for example, *.example.com).
        enable_www_subdomain(bool, optional): Set to true to associate the subdomain www.DomainName  with the App Runner service in addition to the base domain. Default: true . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apprunner.custom_domain.associate(
                ctx, service_arn=value, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apprunner.custom_domain.associate service_arn=value, domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apprunner",
        operation="associate_custom_domain",
        op_kwargs={
            "ServiceArn": service_arn,
            "DomainName": domain_name,
            "EnableWWWSubdomain": enable_www_subdomain,
        },
    )


async def describe_all(
    hub, ctx, service_arn: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Return a description of custom domain names that are associated with an AWS App Runner service.

    Args:
        service_arn(str): The Amazon Resource Name (ARN) of the App Runner service that you want associated custom domain names to be described for.
        next_token(str, optional): A token from a previous result page. It's used for a paginated request. The request retrieves the next result page. All other parameter values must be identical to the ones that are specified in the initial request. If you don't specify NextToken, the request retrieves the first result page. Defaults to None.
        max_results(int, optional): The maximum number of results that each response (result page) can include. It's used for a paginated request. If you don't specify MaxResults, the request retrieves all available results in a single response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apprunner.custom_domain.describe_all(ctx, service_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apprunner.custom_domain.describe_all service_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apprunner",
        operation="describe_custom_domains",
        op_kwargs={
            "ServiceArn": service_arn,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def disassociate(hub, ctx, service_arn: str, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Disassociate a custom domain name from an AWS App Runner service. Certificates tracking domain validity are associated with a custom domain and are stored in AWS Certificate Manager (ACM). These certificates aren't deleted as part of this action. App Runner delays certificate deletion for 30 days after a domain is disassociated from your service.

    Args:
        service_arn(str): The Amazon Resource Name (ARN) of the App Runner service that you want to disassociate a custom domain name from.
        domain_name(str): The domain name that you want to disassociate from the App Runner service.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.apprunner.custom_domain.disassociate(
                ctx, service_arn=value, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.apprunner.custom_domain.disassociate service_arn=value, domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="apprunner",
        operation="disassociate_custom_domain",
        op_kwargs={"ServiceArn": service_arn, "DomainName": domain_name},
    )
